@@ -105,6 +105,12 @@ from .autogen import make_autodocs
 from .setup_docsrc import make_docsrc
 from .call_make import make
 
+from epythet.tools import (
+    repair_package,
+    print_diagnosis,
+    diagnose_doctest_code_blocks,
+    add_newlines_before_doctests_when_missing,
+)
 
 argh_kwargs = {
     'namespace': 'epythet',
